@@ -162,7 +162,7 @@ Returns an alist with insertion details or nil otherwise:
   (interactive)
   (unless (derived-mode-p 'agent-shell-viewport-edit-mode)
     (user-error "Not in a shell viewport buffer"))
-  (when (and (not agent-shell-deferred-initialization)
+  (when (and (not (eq agent-shell-session-strategy 'new-deferred))
              (not (with-current-buffer (agent-shell-viewport--shell-buffer)
                     (map-nested-elt agent-shell--state '(:session :id)))))
     (user-error "Session not ready... please wait"))
@@ -781,6 +781,7 @@ For example, offer to kill associated shell session."
     (define-key map (kbd "C-c C-m") #'agent-shell-viewport-set-session-mode)
     (define-key map (kbd "C-c C-v") #'agent-shell-viewport-set-session-model)
     (define-key map (kbd "C-c C-o") #'agent-shell-other-buffer)
+    (define-key map [remap yank] #'agent-shell-yank-dwim)
     map)
   "Keymap for `agent-shell-viewport-edit-mode'.")
 
